package org.bdware.sc.server;

import org.bdware.doip.audit.EndpointConfig;
import org.bdware.doip.audit.EndpointInfo;
import org.bdware.doip.audit.client.AuditIrpClient;
import org.bdware.doip.audit.server.AuditRequestHandler;
import org.bdware.doip.audit.writer.ConfigurableAuditConfig;
import org.bdware.doip.endpoint.server.DoipListenerConfig;
import org.bdware.doip.endpoint.server.DoipServerImpl;
import org.bdware.doip.endpoint.server.DoipServiceInfo;
import org.bdware.doip.endpoint.server.RepositoryHandler;
import org.bdware.sc.ContractProcess;
import org.bdware.sc.handler.DOOPRepositoryHandler;
import org.bdware.sc.handler.DOOPRequestHandler;
import org.bdware.sc.node.ContractNode;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import static org.bdware.doip.audit.EndpointConfig.defaultDOIPServerPort;
import static org.bdware.doip.audit.EndpointConfig.defaultRepoType;

public class DOOPDoipServer extends DoipServerImpl {
    private final ConfigurableAuditConfig auditConfig;
    EndpointConfig config;
    static AuditIrpClient irpClient;


    public DOOPDoipServer(EndpointConfig config) {
        super(resolveInfo(config));
        this.config = config;
        this.auditConfig = irpClient.getAuditConfig();
    }

    private static DoipServiceInfo resolveInfo(EndpointConfig config) {
        irpClient = new AuditIrpClient(config);
        EndpointInfo info = irpClient.getEndpointInfo();
        if (info == null) {
            String content = "{\"date\":\"2022-1-13\",\"name\":\"testrepoforaibd\",\"doId\":\"bdware.test.local/Repo\",\"address\":\"tcp://127.0.0.1:" + defaultDOIPServerPort + "\",\"status\":\"已审核\",\"protocol\":\"DOIP\",\"pubKey\":\"empty\",\"version\":\"2.1\"}";
            info = EndpointInfo.fromJson(content);
        }
        List<DoipListenerConfig> infos = new ArrayList<>();
        try {
            infos.add(new DoipListenerConfig(info.getURI(), info.getVersion()));
        } catch (Exception e) {
            e.printStackTrace();
        }
        DoipServiceInfo ret = new DoipServiceInfo(info.getDoId(), info.getPubKey(), defaultRepoType, infos);
        return ret;
    }

    @Override
    public void setRepositoryHandler(RepositoryHandler handler) {
        Class clz = DoipServerImpl.class;
        Field f = null;
        try {
            f = clz.getDeclaredField("requestCallback");
            f.setAccessible(true);
//            f.set(this, new DOOPRequestHandler();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
